paidiverpy.utils.static
=======================

.. py:module:: paidiverpy.utils.static

.. autoapi-nested-parse::

   
   Static files for paidiverpy.
















   ..
       !! processed by numpydoc !!


Submodules
----------

.. toctree::
   :maxdepth: 1

   /api/paidiverpy/utils/static/css/index
   /api/paidiverpy/utils/static/html/index
   /api/paidiverpy/utils/static/js/index


